@@ -58,6 +58,7 @@
     MIA <- FALSE
     if (ctrl$MIA) {
         NAs <- data$missings[[j]] ### data[[j, type = "missings"]]
+        NAs <- NAs[NAs %in% subset]
         MIA <- (length(NAs) > 0)
     }
 
@@ -504,16 +505,23 @@ ctree <- function(formula, data, subset, weights, na.action = na.pass, offset, c
             yfun <- ytrafo[[response]]
             rtype <- "user-defined"
         } else {
-            rtype <- class(data[[response]])[1]
-            if (rtype == "integer") rtype <- "numeric"
-            if (rtype == "AsIs") rtype <- "numeric"
+            rtype <- .response_class(data[[response]])
         }
         response <- data[[response]]
 
         infl <- switch(rtype,
             "user-defined" = yfun(response),
             "factor" = {
+                rna <- is.na(response)
                 X <- model.matrix(~ response - 1)
+                ### model.matrix automatically removes rows corresponding to
+                ### missings
+                if (any(rna)) {
+                    ret <- matrix(NA, nrow = NROW(response), ncol = ncol(X))
+                    colnames(ret) <- colnames(X)
+                    ret[!rna,] <- X
+                    X <- ret
+                }
                 if (nlevels(response) > 2) return(X)
                 return(X[,-1, drop = FALSE])
             },
@@ -524,7 +532,8 @@ ctree <- function(formula, data, subset, weights, na.action = na.pass, offset, c
                 return(matrix(sc[as.integer(response)], ncol = 1))
             },
             "numeric" = response,
-            "Surv" = .logrank_trafo(response)
+            "Surv" = .logrank_trafo(response),
+            stop("unknown response class")
         )
     } else {
         ### multivariate response
