@@ -543,7 +543,10 @@ data_party.default <- function(party, id = 1L) {
         ret <- if (nrow(party$data) == 0)
             subset(party$fitted, wi)
         else
-            subset(cbind(party$data, party$fitted), wi)
+            subset(cbind(party$data[, !(names(party$data) %in% 
+                                        names(party$fitted)), 
+                                    drop = FALSE], 
+                         party$fitted), wi)
         ret
     }
     if (length(id) > 1)
@@ -663,7 +666,7 @@ nodeprune.default <- function(x, ids, ...)
         ivar <- varid_split(split)
         svar <- names(dat)[ivar]
         index <- index_split(split)
-        if (is.factor(dat[, svar])) {
+        if (is.factor(dat[, svar]) && !(is.ordered(dat[, svar]) && !is.null(breaks_split(split)))) {
             if (is.null(index)) 
                 index <- ((1:nlevels(dat[, svar])) > breaks_split(split)) + 1
             slevels <- levels(dat[, svar])[index == whichkid]
