@@ -858,6 +858,16 @@ titan <- as.data.frame(Titanic)
 ### prune off nodes 5-12 and check if the other nodes are not affected
 nodeprune(tree, 4)
 
+### subsetting removed weights from fitted, by Jon Peck
+t1 <- ctree(Survived ~Age+Sex+Class, data=Titanic, weights=Freq, maxdepth = 1)
+tita <- as.data.frame(Titanic)
+t2 <- ctree(Survived ~Age+Sex+Class, data=tita[rep(1:nrow(tita), tita$Freq),], maxdepth = 1)
+# all the same
+t1
+t1[1]
+t2
+t2[1]
+
 ### this gave a warning "ME is not a factor"
 if (require("TH.data")) {
     data("mammoexp", package = "TH.data")
@@ -869,3 +879,55 @@ if (require("TH.data")) {
 mt <- lmtree(dist ~ speed, data = cars)
 mt2 <- nodeprune(mt, 2)
 stopifnot(all(mt2$fitted[["(fitted)"]] %in% c(2, 3)))
+
+###
+a <- rep('N',87)
+a[77] <- 'Y'
+b <- rep(FALSE, 87)
+b[c(7,10,11,33,56,77)] <- TRUE
+d <- rep(1,87)
+d[c(29,38,40,42,65,77)] <- 0
+dfb <- data.frame(a = as.factor(a), b = as.factor(b), d = as.factor(d))
+tr <- ctree(a ~ ., data = dfb, control = ctree_control(minsplit = 10,minbucket = 5,
+                                                       maxsurrogate = 2, alpha = 0.05))
+tNodes <- node_party(tr)
+### this creates a tie on purpose and "d" should be selected
+### this check fails on M1mac
+nodeInfo <- info_node(tNodes)
+nodeInfo$criterion
+#stopifnot(names(nodeInfo$p.value) == "d")
+#stopifnot(split_node(tNodes)$varid == 3)
+
+### reported by John Ogawa, 2020-12-11
+class(dfb$a) <- c("Hansi", "factor")
+tr2 <- ctree(a ~ ., data = dfb, control = ctree_control(minsplit = 10,minbucket = 5,
+                                                       maxsurrogate = 2, alpha = 0.05))
+stopifnot(isTRUE(all.equal(tr, tr2, check.attributes = FALSE)))
+
+
+## MIA was applied also in splits w/o missing values
+## reported by Ben Schneider #[50053] 2025-01-29
+d <- data.frame(
+  y = factor(rep(0:1, c(14, 16))),
+  x = factor(c(1, 1, 1, 1, 2, 2, 2, 3, 3, 3, 4, 4, 4, 4, 1, 1, 1, 1, 1, 2, 2, 2,
+3, 3, 3, 4, 4, 4, 4, NA)), 
+  z = c(1, 2, 3, 4, 1, 2, 4, 1, 2, 4, 1, 2, 3, 4, 1, 2, 3, 4, NA, 1, 2, 4, 1, 2,
+3, 1, 2, 3, 4, 1)
+)
+d <- d[rep.int(1:30, c(22, 9, 4, 15, 12, 2, 7, 6, 1, 4, 25, 6, 2, 7, 42, 16,
+3, 31, 1, 7, 3, 7, 1, 1, 3, 22, 3, 4, 18, 1)), ]
+
+ctree(y ~ x + z, data = d, alpha = 0.1, minbucket = 60, MIA = TRUE)
+
+### ctree failed for unordered factor responses with NAs
+### spotted by Jonathan Rinne
+library("partykit")
+d <- cars
+d$dist[1:10] <- NA
+d$speed[11:20] <- NA
+dim(d)
+ctree(dist ~ speed, data = d)
+ctree(dist ~ speed, data = d, subset = !is.na(d$dist))
+d$dist <- cut(d$dist, breaks = c(-Inf, 26, 36, 56, Inf), ordered_result = FALSE)
+ctree(dist ~ speed, data = d)
+ctree(dist ~ speed, data = d, subset = !is.na(d$dist))
